pecos.simulators.sparsesim.cmd\_meas
====================================

.. automodule:: pecos.simulators.sparsesim.cmd_meas







   .. rubric:: Functions

   .. autosummary::

      force_output
      meas_x
      meas_y
      meas_z
      nondeterministic_meas
